@@ -57,22 +57,22 @@ Part::Part( TQWidget *parentWidget, const char *widgetName, TQObject *parent, co
     m_map = new RadialMap::Widget( widget() );
     m_map->hide();
 
-    KStdAction::zoomIn( TQT_TQOBJECT(m_map), TQT_SLOT(zoomIn()), actionCollection() );
-    KStdAction::zoomOut( TQT_TQOBJECT(m_map), TQT_SLOT(zoomOut()), actionCollection() );
-    KStdAction::preferences( this, TQT_SLOT(configFilelight()), actionCollection(), "configure_filelight" )->setText( i18n( "Configure Filelight..." ) );
+    KStdAction::zoomIn( m_map, TQ_SLOT(zoomIn()), actionCollection() );
+    KStdAction::zoomOut( m_map, TQ_SLOT(zoomOut()), actionCollection() );
+    KStdAction::preferences( this, TQ_SLOT(configFilelight()), actionCollection(), "configure_filelight" )->setText( i18n( "Configure Filelight..." ) );
 
-    connect( m_map, TQT_SIGNAL(created( const Directory* )), TQT_SIGNAL(completed()) );
-    connect( m_map, TQT_SIGNAL(created( const Directory* )), TQT_SLOT(mapChanged( const Directory* )) );
-    connect( m_map, TQT_SIGNAL(activated( const KURL& )), TQT_SLOT(updateURL( const KURL& )) );
+    connect( m_map, TQ_SIGNAL(created( const Directory* )), TQ_SIGNAL(completed()) );
+    connect( m_map, TQ_SIGNAL(created( const Directory* )), TQ_SLOT(mapChanged( const Directory* )) );
+    connect( m_map, TQ_SIGNAL(activated( const KURL& )), TQ_SLOT(updateURL( const KURL& )) );
 
     // TODO make better system
-    connect( m_map, TQT_SIGNAL(giveMeTreeFor( const KURL& )), TQT_SLOT(updateURL( const KURL& )) );
-    connect( m_map, TQT_SIGNAL(giveMeTreeFor( const KURL& )), TQT_SLOT(openURL( const KURL& )) );
+    connect( m_map, TQ_SIGNAL(giveMeTreeFor( const KURL& )), TQ_SLOT(updateURL( const KURL& )) );
+    connect( m_map, TQ_SIGNAL(giveMeTreeFor( const KURL& )), TQ_SLOT(openURL( const KURL& )) );
 
-    connect( m_manager, TQT_SIGNAL(completed( Directory* )), TQT_SLOT(scanCompleted( Directory* )) );
-    connect( m_manager, TQT_SIGNAL(aboutToEmptyCache()), m_map, TQT_SLOT(invalidate()) );
+    connect( m_manager, TQ_SIGNAL(completed( Directory* )), TQ_SLOT(scanCompleted( Directory* )) );
+    connect( m_manager, TQ_SIGNAL(aboutToEmptyCache()), m_map, TQ_SLOT(invalidate()) );
 
-    TQTimer::singleShot( 0, this, TQT_SLOT(postInit()) );
+    TQTimer::singleShot( 0, this, TQ_SLOT(postInit()) );
 }
 
 void
@@ -81,7 +81,7 @@ Part::postInit()
    if( m_url.isEmpty() ) //if url is not empty openURL() has been called immediately after ctor, which happens
    {
       TQWidget *summary = new SummaryWidget( widget(), "summaryWidget" );
-      connect( summary, TQT_SIGNAL(activated( const KURL& )), TQT_SLOT(openURL( const KURL& )) );
+      connect( summary, TQ_SIGNAL(activated( const KURL& )), TQ_SLOT(openURL( const KURL& )) );
       summary->show();
 
       //FIXME KXMLGUI is b0rked, it should allow us to set this
@@ -167,8 +167,8 @@ Part::configFilelight()
 {
     TQWidget *dialog = new SettingsDialog( widget(), "settings_dialog" );
 
-    connect( dialog, TQT_SIGNAL(canvasIsDirty( int )), m_map, TQT_SLOT(refresh( int )) );
-    connect( dialog, TQT_SIGNAL(mapIsInvalid()), m_manager, TQT_SLOT(emptyCache()) );
+    connect( dialog, TQ_SIGNAL(canvasIsDirty( int )), m_map, TQ_SLOT(refresh( int )) );
+    connect( dialog, TQ_SIGNAL(mapIsInvalid()), m_manager, TQ_SLOT(emptyCache()) );
 
     dialog->show(); //deletes itself
 }
@@ -184,8 +184,8 @@ Part::start( const KURL &url )
 {
    if( !m_started ) {
       m_statusbar->addStatusBarItem( new ProgressBox( statusBar(), this ), 0, true );
-      connect( m_map, TQT_SIGNAL(mouseHover( const TQString& )), statusBar(), TQT_SLOT(message( const TQString& )) );
-      connect( m_map, TQT_SIGNAL(created( const Directory* )), statusBar(), TQT_SLOT(clear()) );
+      connect( m_map, TQ_SIGNAL(mouseHover( const TQString& )), statusBar(), TQ_SLOT(message( const TQString& )) );
+      connect( m_map, TQ_SIGNAL(created( const Directory* )), statusBar(), TQ_SLOT(clear()) );
       m_started = true;
    }
 
@@ -230,7 +230,7 @@ Part::scanCompleted( Directory *tree )
       emit setWindowCaption( TQString() );
 
       statusBar()->clear();
-//      TQTimer::singleShot( 2000, statusBar(), TQT_SLOT(clear()) );
+//      TQTimer::singleShot( 2000, statusBar(), TQ_SLOT(clear()) );
 
       m_url = KURL();
    }
@@ -243,7 +243,7 @@ Part::mapChanged( const Directory *tree )
 
    emit setWindowCaption( prettyURL() );
 
-   ProgressBox *progress = static_cast<ProgressBox *>(TQT_TQWIDGET(statusBar()->child( "ProgressBox" )));
+   ProgressBox *progress = static_cast<ProgressBox *>(statusBar()->child( "ProgressBox" ));
 
    if( progress )
       progress->setText( tree->children() );
